@@ -27,6 +27,8 @@
 
 gsl_error_handler_t * gsl_error_handler = NULL;
 
+static void no_error_handler (const char *reason, const char *file, int line, int gsl_errno);
+
 void
 gsl_error (const char * reason, const char * file, int line, int gsl_errno)
 {
@@ -49,3 +51,23 @@ gsl_set_error_handler (gsl_error_handler_t * new_handler)
 }
 
 
+gsl_error_handler_t *
+gsl_set_error_handler_off (void)
+{
+  gsl_error_handler_t * previous_handler = gsl_error_handler;
+  gsl_error_handler = no_error_handler;
+  return previous_handler;
+}
+
+static void
+no_error_handler (const char *reason, const char *file, int line, int gsl_errno)
+{
+  /* do nothing */
+  reason = 0;
+  file = 0;
+  line = 0;
+  gsl_errno = 0;
+  return;
+}
+
+
