@@ -25,12 +25,12 @@ FUNCTION(fft_complex,pass_7) (const BASE in[],
 			      const gsl_fft_direction sign,
 			      const size_t product,
 			      const size_t n,
-			      const gsl_complex twiddle1[],
-			      const gsl_complex twiddle2[],
-			      const gsl_complex twiddle3[],
-			      const gsl_complex twiddle4[],
-			      const gsl_complex twiddle5[],
-			      const gsl_complex twiddle6[])
+			      const TYPE(gsl_complex) twiddle1[],
+			      const TYPE(gsl_complex) twiddle2[],
+			      const TYPE(gsl_complex) twiddle3[],
+			      const TYPE(gsl_complex) twiddle4[],
+			      const TYPE(gsl_complex) twiddle5[],
+			      const TYPE(gsl_complex) twiddle6[])
 {
   size_t i = 0, j = 0;
   size_t k, k1;
