@@ -1,10 +1,29 @@
+/* fft/factorize.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
-#include <gsl_errno.h>
-#include <gsl_fft_complex.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_fft_complex.h>
 
 #include "factorize.h"
 
-int
+static int
 fft_complex_factorize (const size_t n,
 			   size_t *nf,
 			   size_t factors[])
@@ -19,7 +38,7 @@ fft_complex_factorize (const size_t n,
   return status;
 }
 
-int
+static int
 fft_halfcomplex_factorize (const size_t n,
 			       size_t *nf,
 			       size_t factors[])
@@ -31,7 +50,7 @@ fft_halfcomplex_factorize (const size_t n,
   return status;
 }
 
-int
+static int
 fft_real_factorize (const size_t n,
 			size_t *nf,
 			size_t factors[])
@@ -44,7 +63,7 @@ fft_real_factorize (const size_t n,
 }
 
 
-int
+static int
 fft_factorize (const size_t n,
 		   const size_t implemented_subtransforms[],
 		   size_t *n_factors,
@@ -129,7 +148,8 @@ fft_factorize (const size_t n,
 }
 
 
-int fft_binary_logn (const size_t n)
+static int 
+fft_binary_logn (const size_t n)
 {
   size_t ntest ;
   size_t binary_logn = 0 ;
