@@ -26,7 +26,7 @@ FUNCTION(fft_halfcomplex,pass_2) (const BASE in[],
 				  const size_t ostride,
 				  const size_t product,
 				  const size_t n,
-				  const gsl_complex twiddle[]);
+				  const TYPE(gsl_complex) twiddle[]);
 
 static void
 FUNCTION(fft_halfcomplex,pass_3) (const BASE in[], 
@@ -35,8 +35,8 @@ FUNCTION(fft_halfcomplex,pass_3) (const BASE in[],
 				  const size_t ostride,
 				  const size_t product,
 				  const size_t n,
-				  const gsl_complex twiddle1[],
-				  const gsl_complex twiddle2[]);
+				  const TYPE(gsl_complex) twiddle1[],
+				  const TYPE(gsl_complex) twiddle2[]);
 
 static void
 FUNCTION(fft_halfcomplex,pass_4) (const BASE in[],
@@ -45,9 +45,9 @@ FUNCTION(fft_halfcomplex,pass_4) (const BASE in[],
 				  const size_t ostride,
 				  const size_t product,
 				  const size_t n,
-				  const gsl_complex twiddle1[],
-				  const gsl_complex twiddle2[],
-				  const gsl_complex twiddle3[]);
+				  const TYPE(gsl_complex) twiddle1[],
+				  const TYPE(gsl_complex) twiddle2[],
+				  const TYPE(gsl_complex) twiddle3[]);
 
 static void
 FUNCTION(fft_halfcomplex,pass_5) (const BASE in[],
@@ -56,10 +56,10 @@ FUNCTION(fft_halfcomplex,pass_5) (const BASE in[],
 				  const size_t ostride,
 				  const size_t product,
 				  const size_t n,
-				  const gsl_complex twiddle1[],
-				  const gsl_complex twiddle2[],
-				  const gsl_complex twiddle3[],
-				  const gsl_complex twiddle4[]);
+				  const TYPE(gsl_complex) twiddle1[],
+				  const TYPE(gsl_complex) twiddle2[],
+				  const TYPE(gsl_complex) twiddle3[],
+				  const TYPE(gsl_complex) twiddle4[]);
 
 static void
 FUNCTION(fft_halfcomplex,pass_n) (const BASE in[],
@@ -69,7 +69,7 @@ FUNCTION(fft_halfcomplex,pass_n) (const BASE in[],
 				  const size_t factor,
 				  const size_t product,
 				  const size_t n,
-				  const gsl_complex twiddle[]);
+				  const TYPE(gsl_complex) twiddle[]);
 
 
 
