@@ -21,6 +21,8 @@
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_histogram.h>
 
+#include "find.c"
+
 int
 gsl_histogram_increment (gsl_histogram * h, double x)
 {
@@ -34,14 +36,14 @@ gsl_histogram_accumulate (gsl_histogram * h, double x, double weight)
   const size_t n = h->n;
   size_t index = 0;
 
-  int status = gsl_histogram_find_impl (h->n, h->range, x, &index);
+  int status = find (h->n, h->range, x, &index);
 
   if (status)
     {
       return GSL_EDOM;
     }
 
-  if (index > n)
+  if (index >= n)
     {
       GSL_ERROR ("index lies outside valid range of 0 .. n - 1",
 		 GSL_ESANITY);
