@@ -25,7 +25,7 @@
 #include <gsl/gsl_blas.h>
 #include <gsl/gsl_complex_math.h>
 
-#include "gsl_linalg.h"
+#include <gsl/gsl_linalg.h>
 
 gsl_complex
 gsl_linalg_complex_householder_transform (gsl_vector_complex * v)
