@@ -25,7 +25,7 @@
 #include <gsl/gsl_matrix.h>
 #include <gsl/gsl_blas.h>
 
-#include "gsl_linalg.h"
+#include <gsl/gsl_linalg.h>
 
 #include "givens.c"
 #include "svdstep.c"
