@@ -202,7 +202,7 @@ int gsl_matrix_float_fscanf (FILE * stream, gsl_matrix_float * m);
 int gsl_matrix_float_fprintf (FILE * stream, const gsl_matrix_float * m, const char * format);
  
 int gsl_matrix_float_memcpy(gsl_matrix_float * dest, const gsl_matrix_float * src);
-int gsl_matrix_float_swap(gsl_matrix_float * m1, const gsl_matrix_float * m2);
+int gsl_matrix_float_swap(gsl_matrix_float * m1, gsl_matrix_float * m2);
 
 int gsl_matrix_float_swap_rows(gsl_matrix_float * m, const size_t i, const size_t j);
 int gsl_matrix_float_swap_columns(gsl_matrix_float * m, const size_t i, const size_t j);
@@ -226,6 +226,7 @@ int gsl_matrix_float_mul_elements (gsl_matrix_float * a, const gsl_matrix_float
 int gsl_matrix_float_div_elements (gsl_matrix_float * a, const gsl_matrix_float * b);
 int gsl_matrix_float_scale (gsl_matrix_float * a, const double x);
 int gsl_matrix_float_add_constant (gsl_matrix_float * a, const double x);
+int gsl_matrix_float_add_diagonal (gsl_matrix_float * a, const double x);
 
 /***********************************************************************/
 /* The functions below are obsolete                                    */
