@@ -202,7 +202,7 @@ int gsl_matrix_int_fscanf (FILE * stream, gsl_matrix_int * m);
 int gsl_matrix_int_fprintf (FILE * stream, const gsl_matrix_int * m, const char * format);
  
 int gsl_matrix_int_memcpy(gsl_matrix_int * dest, const gsl_matrix_int * src);
-int gsl_matrix_int_swap(gsl_matrix_int * m1, const gsl_matrix_int * m2);
+int gsl_matrix_int_swap(gsl_matrix_int * m1, gsl_matrix_int * m2);
 
 int gsl_matrix_int_swap_rows(gsl_matrix_int * m, const size_t i, const size_t j);
 int gsl_matrix_int_swap_columns(gsl_matrix_int * m, const size_t i, const size_t j);
@@ -226,6 +226,7 @@ int gsl_matrix_int_mul_elements (gsl_matrix_int * a, const gsl_matrix_int * b);
 int gsl_matrix_int_div_elements (gsl_matrix_int * a, const gsl_matrix_int * b);
 int gsl_matrix_int_scale (gsl_matrix_int * a, const double x);
 int gsl_matrix_int_add_constant (gsl_matrix_int * a, const double x);
+int gsl_matrix_int_add_diagonal (gsl_matrix_int * a, const double x);
 
 /***********************************************************************/
 /* The functions below are obsolete                                    */
