@@ -202,7 +202,7 @@ int gsl_matrix_short_fscanf (FILE * stream, gsl_matrix_short * m);
 int gsl_matrix_short_fprintf (FILE * stream, const gsl_matrix_short * m, const char * format);
  
 int gsl_matrix_short_memcpy(gsl_matrix_short * dest, const gsl_matrix_short * src);
-int gsl_matrix_short_swap(gsl_matrix_short * m1, const gsl_matrix_short * m2);
+int gsl_matrix_short_swap(gsl_matrix_short * m1, gsl_matrix_short * m2);
 
 int gsl_matrix_short_swap_rows(gsl_matrix_short * m, const size_t i, const size_t j);
 int gsl_matrix_short_swap_columns(gsl_matrix_short * m, const size_t i, const size_t j);
@@ -226,6 +226,7 @@ int gsl_matrix_short_mul_elements (gsl_matrix_short * a, const gsl_matrix_short
 int gsl_matrix_short_div_elements (gsl_matrix_short * a, const gsl_matrix_short * b);
 int gsl_matrix_short_scale (gsl_matrix_short * a, const double x);
 int gsl_matrix_short_add_constant (gsl_matrix_short * a, const double x);
+int gsl_matrix_short_add_diagonal (gsl_matrix_short * a, const double x);
 
 /***********************************************************************/
 /* The functions below are obsolete                                    */
