@@ -49,12 +49,16 @@ typedef struct
 typedef struct
 {
   gsl_matrix_ulong matrix;
-} gsl_matrix_ulong_view;
+} _gsl_matrix_ulong_view;
+
+typedef _gsl_matrix_ulong_view gsl_matrix_ulong_view;
 
 typedef struct
 {
-  const gsl_matrix_ulong matrix;
-} gsl_matrix_ulong_const_view;
+  gsl_matrix_ulong matrix;
+} _gsl_matrix_ulong_const_view;
+
+typedef const _gsl_matrix_ulong_const_view gsl_matrix_ulong_const_view;
 
 /* Allocation */
 
@@ -90,91 +94,91 @@ void gsl_matrix_ulong_free (gsl_matrix_ulong * m);
 
 /* Views */
 
-gsl_matrix_ulong_view 
+_gsl_matrix_ulong_view 
 gsl_matrix_ulong_submatrix (gsl_matrix_ulong * m, 
                             const size_t i, const size_t j, 
                             const size_t n1, const size_t n2);
 
-gsl_vector_ulong_view 
+_gsl_vector_ulong_view 
 gsl_matrix_ulong_row (gsl_matrix_ulong * m, const size_t i);
 
-gsl_vector_ulong_view 
+_gsl_vector_ulong_view 
 gsl_matrix_ulong_column (gsl_matrix_ulong * m, const size_t j);
 
-gsl_vector_ulong_view 
+_gsl_vector_ulong_view 
 gsl_matrix_ulong_diagonal (gsl_matrix_ulong * m);
 
-gsl_vector_ulong_view 
+_gsl_vector_ulong_view 
 gsl_matrix_ulong_subdiagonal (gsl_matrix_ulong * m, const size_t k);
 
-gsl_vector_ulong_view 
+_gsl_vector_ulong_view 
 gsl_matrix_ulong_superdiagonal (gsl_matrix_ulong * m, const size_t k);
 
-gsl_matrix_ulong_view
+_gsl_matrix_ulong_view
 gsl_matrix_ulong_view_array (unsigned long * base,
                              const size_t n1, 
                              const size_t n2);
 
-gsl_matrix_ulong_view
+_gsl_matrix_ulong_view
 gsl_matrix_ulong_view_array_with_tda (unsigned long * base, 
                                       const size_t n1, 
                                       const size_t n2,
                                       const size_t tda);
 
 
-gsl_matrix_ulong_view
+_gsl_matrix_ulong_view
 gsl_matrix_ulong_view_vector (gsl_vector_ulong * v,
                               const size_t n1, 
                               const size_t n2);
 
-gsl_matrix_ulong_view
+_gsl_matrix_ulong_view
 gsl_matrix_ulong_view_vector_with_tda (gsl_vector_ulong * v,
                                        const size_t n1, 
                                        const size_t n2,
                                        const size_t tda);
 
 
-gsl_matrix_ulong_const_view 
+_gsl_matrix_ulong_const_view 
 gsl_matrix_ulong_const_submatrix (const gsl_matrix_ulong * m, 
                                   const size_t i, const size_t j, 
                                   const size_t n1, const size_t n2);
 
-gsl_vector_ulong_const_view 
+_gsl_vector_ulong_const_view 
 gsl_matrix_ulong_const_row (const gsl_matrix_ulong * m, 
                             const size_t i);
 
-gsl_vector_ulong_const_view 
+_gsl_vector_ulong_const_view 
 gsl_matrix_ulong_const_column (const gsl_matrix_ulong * m, 
                                const size_t j);
 
-gsl_vector_ulong_const_view
+_gsl_vector_ulong_const_view
 gsl_matrix_ulong_const_diagonal (const gsl_matrix_ulong * m);
 
-gsl_vector_ulong_const_view 
+_gsl_vector_ulong_const_view 
 gsl_matrix_ulong_const_subdiagonal (const gsl_matrix_ulong * m, 
                                     const size_t k);
 
-gsl_vector_ulong_const_view 
+_gsl_vector_ulong_const_view 
 gsl_matrix_ulong_const_superdiagonal (const gsl_matrix_ulong * m, 
                                       const size_t k);
 
-gsl_matrix_ulong_const_view
+_gsl_matrix_ulong_const_view
 gsl_matrix_ulong_const_view_array (const unsigned long * base,
                                    const size_t n1, 
                                    const size_t n2);
 
-gsl_matrix_ulong_const_view
+_gsl_matrix_ulong_const_view
 gsl_matrix_ulong_const_view_array_with_tda (const unsigned long * base, 
                                             const size_t n1, 
                                             const size_t n2,
                                             const size_t tda);
 
-gsl_matrix_ulong_const_view
+_gsl_matrix_ulong_const_view
 gsl_matrix_ulong_const_view_vector (const gsl_vector_ulong * v,
                                     const size_t n1, 
                                     const size_t n2);
 
-gsl_matrix_ulong_const_view
+_gsl_matrix_ulong_const_view
 gsl_matrix_ulong_const_view_vector_with_tda (const gsl_vector_ulong * v,
                                              const size_t n1, 
                                              const size_t n2,
@@ -198,7 +202,7 @@ int gsl_matrix_ulong_fscanf (FILE * stream, gsl_matrix_ulong * m);
 int gsl_matrix_ulong_fprintf (FILE * stream, const gsl_matrix_ulong * m, const char * format);
  
 int gsl_matrix_ulong_memcpy(gsl_matrix_ulong * dest, const gsl_matrix_ulong * src);
-int gsl_matrix_ulong_swap(gsl_matrix_ulong * m1, const gsl_matrix_ulong * m2);
+int gsl_matrix_ulong_swap(gsl_matrix_ulong * m1, gsl_matrix_ulong * m2);
 
 int gsl_matrix_ulong_swap_rows(gsl_matrix_ulong * m, const size_t i, const size_t j);
 int gsl_matrix_ulong_swap_columns(gsl_matrix_ulong * m, const size_t i, const size_t j);
@@ -222,6 +226,7 @@ int gsl_matrix_ulong_mul_elements (gsl_matrix_ulong * a, const gsl_matrix_ulong
 int gsl_matrix_ulong_div_elements (gsl_matrix_ulong * a, const gsl_matrix_ulong * b);
 int gsl_matrix_ulong_scale (gsl_matrix_ulong * a, const double x);
 int gsl_matrix_ulong_add_constant (gsl_matrix_ulong * a, const double x);
+int gsl_matrix_ulong_add_diagonal (gsl_matrix_ulong * a, const double x);
 
 /***********************************************************************/
 /* The functions below are obsolete                                    */
