@@ -22,7 +22,7 @@
 #include <math.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_math.h>
-#include "gsl_odeiv.h"
+#include <gsl/gsl_odeiv.h>
 
 typedef struct
 {
