@@ -27,7 +27,7 @@
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
 #include "odeiv_util.h"
-#include "gsl_odeiv.h"
+#include <gsl/gsl_odeiv.h>
 
 
 /* gear2 state object */
