@@ -26,7 +26,7 @@
 #include <string.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include "gsl_odeiv.h"
+#include <gsl/gsl_odeiv.h>
 
 #include "odeiv_util.h"
 
