@@ -1,12 +1,31 @@
+/* poly/zsolve.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* zsolve.c - finds the complex roots of  = 0 */
 
 #include <config.h>
 #include <math.h>
 #include <stdlib.h>
-#include <gsl_math.h>
-#include <gsl_errno.h>
-#include <gsl_complex.h>
-#include <gsl_poly.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_complex.h>
+#include <gsl/gsl_poly.h>
 
 /* C-style matrix elements */
 #define MAT(m,i,j,n) ((m)[(i)*(n) + (j)])
