@@ -57,19 +57,26 @@ gsl_rng;
 /* These structs also need to appear in default.c so you can select
    them via the environment variable GSL_RNG_TYPE */
 
+extern const gsl_rng_type *gsl_rng_borosh13;
+extern const gsl_rng_type *gsl_rng_coveyou;
 extern const gsl_rng_type *gsl_rng_cmrg;
+extern const gsl_rng_type *gsl_rng_fishman18;
+extern const gsl_rng_type *gsl_rng_fishman20;
+extern const gsl_rng_type *gsl_rng_fishman2x;
 extern const gsl_rng_type *gsl_rng_gfsr4;
+extern const gsl_rng_type *gsl_rng_knuthran;
+extern const gsl_rng_type *gsl_rng_knuthran2;
+extern const gsl_rng_type *gsl_rng_lecuyer21;
 extern const gsl_rng_type *gsl_rng_minstd;
 extern const gsl_rng_type *gsl_rng_mrg;
 extern const gsl_rng_type *gsl_rng_mt19937;
-extern const gsl_rng_type *gsl_rng_mt19937_1998;
 extern const gsl_rng_type *gsl_rng_r250;
 extern const gsl_rng_type *gsl_rng_ran0;
 extern const gsl_rng_type *gsl_rng_ran1;
 extern const gsl_rng_type *gsl_rng_ran2;
 extern const gsl_rng_type *gsl_rng_ran3;
-extern const gsl_rng_type *gsl_rng_rand48;
 extern const gsl_rng_type *gsl_rng_rand;
+extern const gsl_rng_type *gsl_rng_rand48;
 extern const gsl_rng_type *gsl_rng_random128_bsd;
 extern const gsl_rng_type *gsl_rng_random128_glibc2;
 extern const gsl_rng_type *gsl_rng_random128_libc5;
@@ -90,8 +97,8 @@ extern const gsl_rng_type *gsl_rng_random_glibc2;
 extern const gsl_rng_type *gsl_rng_random_libc5;
 extern const gsl_rng_type *gsl_rng_randu;
 extern const gsl_rng_type *gsl_rng_ranf;
-extern const gsl_rng_type *gsl_rng_ranlux389;
 extern const gsl_rng_type *gsl_rng_ranlux;
+extern const gsl_rng_type *gsl_rng_ranlux389;
 extern const gsl_rng_type *gsl_rng_ranlxd1;
 extern const gsl_rng_type *gsl_rng_ranlxd2;
 extern const gsl_rng_type *gsl_rng_ranlxs0;
@@ -102,9 +109,10 @@ extern const gsl_rng_type *gsl_rng_slatec;
 extern const gsl_rng_type *gsl_rng_taus;
 extern const gsl_rng_type *gsl_rng_transputer;
 extern const gsl_rng_type *gsl_rng_tt800;
-extern const gsl_rng_type *gsl_rng_uni32;
 extern const gsl_rng_type *gsl_rng_uni;
+extern const gsl_rng_type *gsl_rng_uni32;
 extern const gsl_rng_type *gsl_rng_vax;
+extern const gsl_rng_type *gsl_rng_waterman14;
 extern const gsl_rng_type *gsl_rng_zuf;
 
 const gsl_rng_type ** gsl_rng_types_setup(void);
