@@ -1,7 +1,26 @@
+/* rng/rand48.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 James Theiler, Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 #include <math.h>
 #include <stdlib.h>
-#include <gsl_rng.h>
+#include <gsl/gsl_rng.h>
 
 /* This is the Unix rand48() generator. The generator returns the
    upper 32 bits from each term of the sequence,
@@ -17,9 +36,9 @@
    The period of this generator is ? FIXME (probably around 2^48). */
 
 static inline void rand48_advance (void *vstate);
-unsigned long int rand48_get (void *vstate);
-double rand48_get_double (void *vstate);
-void rand48_set (void *state, unsigned long int s);
+static unsigned long int rand48_get (void *vstate);
+static double rand48_get_double (void *vstate);
+static void rand48_set (void *state, unsigned long int s);
 
 static const unsigned short int a0 = 0xE66D ;
 static const unsigned short int a1 = 0xDEEC ;
@@ -63,7 +82,7 @@ rand48_advance (void *vstate)
   state->x2 = (a & 0xFFFF) ;
 }
 
-unsigned long int 
+static unsigned long int 
 rand48_get (void *vstate)
 {
   unsigned long int x1, x2;
@@ -77,7 +96,7 @@ rand48_get (void *vstate)
   return (x2 << 16) + x1;
 }
 
-double
+static double
 rand48_get_double (void * vstate)
 {
   rand48_state_t *state = (rand48_state_t *) vstate;
@@ -89,7 +108,7 @@ rand48_get_double (void * vstate)
 	  + ldexp((double) state->x0, -48)) ;
 }
 
-void
+static void
 rand48_set (void *vstate, unsigned long int s)
 {
   rand48_state_t *state = (rand48_state_t *) vstate;
