@@ -32,19 +32,26 @@ gsl_rng_types_setup (void)
 {
   int i = 0;
 
+  ADD(gsl_rng_borosh13);
   ADD(gsl_rng_cmrg);
+  ADD(gsl_rng_coveyou);
+  ADD(gsl_rng_fishman18);
+  ADD(gsl_rng_fishman20);
+  ADD(gsl_rng_fishman2x);
   ADD(gsl_rng_gfsr4);
+  ADD(gsl_rng_knuthran);
+  ADD(gsl_rng_knuthran2);
+  ADD(gsl_rng_lecuyer21);
   ADD(gsl_rng_minstd);
   ADD(gsl_rng_mrg);
   ADD(gsl_rng_mt19937);
-  ADD(gsl_rng_mt19937_1998);
   ADD(gsl_rng_r250);
   ADD(gsl_rng_ran0);
   ADD(gsl_rng_ran1);
   ADD(gsl_rng_ran2);
   ADD(gsl_rng_ran3);
-  ADD(gsl_rng_rand48);
   ADD(gsl_rng_rand);
+  ADD(gsl_rng_rand48);
   ADD(gsl_rng_random128_bsd);
   ADD(gsl_rng_random128_glibc2);
   ADD(gsl_rng_random128_libc5);
@@ -65,8 +72,8 @@ gsl_rng_types_setup (void)
   ADD(gsl_rng_random_libc5);
   ADD(gsl_rng_randu);
   ADD(gsl_rng_ranf);
-  ADD(gsl_rng_ranlux389);
   ADD(gsl_rng_ranlux);
+  ADD(gsl_rng_ranlux389);
   ADD(gsl_rng_ranlxd1);
   ADD(gsl_rng_ranlxd2);
   ADD(gsl_rng_ranlxs0);
@@ -77,9 +84,10 @@ gsl_rng_types_setup (void)
   ADD(gsl_rng_taus);
   ADD(gsl_rng_transputer);
   ADD(gsl_rng_tt800);
-  ADD(gsl_rng_uni32);
   ADD(gsl_rng_uni);
+  ADD(gsl_rng_uni32);
   ADD(gsl_rng_vax);
+  ADD(gsl_rng_waterman14);
   ADD(gsl_rng_zuf);
   ADD(0);
 
