@@ -22,11 +22,11 @@
 #include <config.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include "gsl_sf_pow_int.h"
+#include <gsl/gsl_sf_pow_int.h>
 #include "bessel.h"
 #include "bessel_amp_phase.h"
 #include "bessel_olver.h"
-#include "gsl_sf_bessel.h"
+#include <gsl/gsl_sf_bessel.h>
 
 
 
