@@ -22,10 +22,10 @@
 #include <config.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include "gsl_sf_exp.h"
-#include "gsl_sf_gamma.h"
-#include "gsl_sf_trig.h"
-#include "gsl_sf_legendre.h"
+#include <gsl/gsl_sf_exp.h>
+#include <gsl/gsl_sf_gamma.h>
+#include <gsl/gsl_sf_trig.h>
+#include <gsl/gsl_sf_legendre.h>
 
 #include "error.h"
 
