@@ -49,12 +49,16 @@ gsl_vector;
 typedef struct
 {
   gsl_vector vector;
-} gsl_vector_view;
+} _gsl_vector_view;
+
+typedef _gsl_vector_view gsl_vector_view;
 
 typedef struct
 {
-  const gsl_vector vector;
-} gsl_vector_const_view;
+  gsl_vector vector;
+} _gsl_vector_const_view;
+
+typedef const _gsl_vector_const_view gsl_vector_const_view;
 
 
 /* Allocation */
@@ -76,39 +80,39 @@ void gsl_vector_free (gsl_vector * v);
 
 /* Views */
 
-gsl_vector_view 
+_gsl_vector_view 
 gsl_vector_view_array (double *v, size_t n);
 
-gsl_vector_view 
+_gsl_vector_view 
 gsl_vector_view_array_with_stride (double *base,
                                          size_t stride,
                                          size_t n);
 
-gsl_vector_const_view 
+_gsl_vector_const_view 
 gsl_vector_const_view_array (const double *v, size_t n);
 
-gsl_vector_const_view 
+_gsl_vector_const_view 
 gsl_vector_const_view_array_with_stride (const double *base,
                                                size_t stride,
                                                size_t n);
 
-gsl_vector_view 
+_gsl_vector_view 
 gsl_vector_subvector (gsl_vector *v, 
                             size_t i, 
                             size_t n);
 
-gsl_vector_view 
+_gsl_vector_view 
 gsl_vector_subvector_with_stride (gsl_vector *v, 
                                         size_t i,
                                         size_t stride,
                                         size_t n);
 
-gsl_vector_const_view 
+_gsl_vector_const_view 
 gsl_vector_const_subvector (const gsl_vector *v, 
                                   size_t i, 
                                   size_t n);
 
-gsl_vector_const_view 
+_gsl_vector_const_view 
 gsl_vector_const_subvector_with_stride (const gsl_vector *v, 
                                               size_t i, 
                                               size_t stride,
